aboutsummaryrefslogtreecommitdiffstats
path: root/libical/src/libicalvcal/vcc.c
diff options
context:
space:
mode:
Diffstat (limited to 'libical/src/libicalvcal/vcc.c')
-rw-r--r--libical/src/libicalvcal/vcc.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/libical/src/libicalvcal/vcc.c b/libical/src/libicalvcal/vcc.c
index 313e5d6d80..ea916781df 100644
--- a/libical/src/libicalvcal/vcc.c
+++ b/libical/src/libicalvcal/vcc.c
@@ -1,7 +1,6 @@
/* A Bison parser, made from vcc.y
- by GNU Bison version 1.27
- */
+ by GNU Bison version 1.28 */
#define YYBISON 1 /* Identify Bison output. */
@@ -370,7 +369,7 @@ static const short yycheck[] = { 7,
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
/* This file comes from bison-1.27. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -583,7 +582,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
#endif
#endif
-#line 216 "/usr/lib/bison.simple"
+#line 217 "/usr/lib/bison.simple"
/* The user can define YYPARSE_PARAM as the name of an argument to be passed
into yyparse. The argument should have type void *.
@@ -1072,7 +1071,7 @@ case 46:
break;}
}
/* the action file gets copied in in place of this dollarsign */
-#line 542 "/usr/lib/bison.simple"
+#line 543 "/usr/lib/bison.simple"
yyvsp -= yylen;
yyssp -= yylen;
@@ -370,7 +369,7 @@ static const short yycheck[] = { 7,
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
-/* This file comes from bison-1.27. */
+/* This file comes from bison-1.28. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.